MESSAGE_ENTRY = {
    "rec_name_01": {
        "zh_CN": "负买电电价收益优化",
        "en_US": "Optimization of the revenue from negative import electricity prices.",
    },
    "rec_name_02": {
        "zh_CN": "负卖电电价收益优化",
        "en_US": "Optimization of the revenue from negative export electricity prices.",
    },
    "instruction_01": {
        "zh_CN": "当买电电价为负时，调整光伏和储能功率，将光伏功率降为最低，尽量从市电买电为电池充电",
        "en_US": "When the electricity purchase price is negative, adjust the power of the photovoltaic system and the energy storage system. Reduce the photovoltaic power to the minimum and try to purchase electricity from the municipal power grid as much as possible to charge the battery.",
    },
    "instruction_02": {
        "zh_CN": "当卖电电价为负时，调整系统馈网功率，不向电网馈电",
        "en_US": "When the electricity selling price is negative, adjust the power fed back to the grid by the system and refrain from feeding power back to the grid.",
    },
    "IF": {"zh_CN": "IF条件", "en_US": "IF"},
    "THEN": {"zh_CN": "THEN动作", "en_US": "THEN"},
    "date": {"zh_CN": "日期: \n\t", "en_US": "Date: \n\t"},
    "time": {"zh_CN": "时间", "en_US": "Time"},
    "103": {"zh_CN": "仅一次", "en_US": "Once"},
    "104": {"zh_CN": "每天", "en_US": "Everyday"},
    "105": {"zh_CN": "工作日", "en_US": "Weekdays"},
    "106": {"zh_CN": "周末", "en_US": "Weekends"},
    "1": {"zh_CN": "周一", "en_US": "Mon"},
    "2": {"zh_CN": "周二", "en_US": "Tues"},
    "3": {"zh_CN": "周三", "en_US": "Wed"},
    "4": {"zh_CN": "周四", "en_US": "Thur"},
    "5": {"zh_CN": "周五", "en_US": "Fri"},
    "6": {"zh_CN": "周六", "en_US": "Sat"},
    "7": {"zh_CN": "周日", "en_US": "Sun"},
    "weather": {"zh_CN": "天气: \n\t", "en_US": "Weather: \n\t"},
    "irradiance": {
        "zh_CN": "太阳辐照度 {} {}W/m² 且一天内累计有 {} 小时大于200W/m²",
        "en_US": "The solar irradiance {} {}W/m², and totally there are {} hours in a day with a solar irradiance greater than 200W/m²",
    },
    "temperature": {"zh_CN": "温度 {} {} ℃", "en_US": "Temperature {} {} ℃"},
    "humidity": {"zh_CN": "湿度 {} {} %RH", "en_US": "Humidity {} {} %RH"},
    "wind": {"zh_CN": "风速 {} {} m/s", "en_US": "Wind speed {} {} m/s"},
    "barometricPressure": {
        "zh_CN": "气压 {} {} hPa",
        "en_US": "Air pressure {} {} hPa",
    },
    "rain": {"zh_CN": "{} 下雨", "en_US": "It {} rain"},
    "108": {"zh_CN": "会", "en_US": "will"},
    "109": {"zh_CN": "不会", "en_US": "won''t"},
    "forcastRain": {
        "zh_CN": "未来 {} 小时会下雨",
        "en_US": "It will rain in the next {} hours",
    },
    "100": {"zh_CN": "大于", "en_US": "is greater than"},
    "101": {"zh_CN": "小于", "en_US": "is less than"},
    "102": {"zh_CN": "等于", "en_US": "is equal to"},
    "electricityPrice": {"zh_CN": "电价: \n\t", "en_US": "Electricity price: \n\t"},
    "buyingPrice": {"zh_CN": "买电电价\n\t", "en_US": "Import price\n\t"},
    "sellingPrice": {"zh_CN": "卖电电价\n\t", "en_US": "Export price\n\t"},
    "price": {"zh_CN": "电价 {} {}{}", "en_US": "Electricity price {} {}{}"},
    "lowerPrice": {
        "zh_CN": "比最高的电价低 {}{}",
        "en_US": "Lower than the highest electricity price by {}{} ",
    },
    "higherPrice": {
        "zh_CN": "比最低的电价高 {}{}",
        "en_US": "Higher than the lowest electricity price by {}{} ",
    },
    "expensiveHours": {
        "zh_CN": "在 {} 到 {} 期间，电价最高的 {}小时",
        "en_US": "During the period from {} to {}, the {}h with the highest electricity price",
    },
    "cheapestHours": {
        "zh_CN": "在 {} 到 {} 期间，电价最低的 {} 小时",
        "en_US": "During the period from {} to {}, the {}h with the lowest electricity price",
    },
    "system": {"zh_CN": "系统动作\n\t", "en_US": "System\n\t"},
    "systemSwitch": {"zh_CN": "系统开关 {}", "en_US": "System {}"},
    "on": {"zh_CN": "开", "en_US": "ON"},
    "off": {"zh_CN": "关", "en_US": "OFF"},
    "exportControl": {
        "zh_CN": "馈网控制 {}, {}, 设置值为 {}{}",
        "en_US": "Export_control {}, the mode is {}, the value is {}{}",
    },
    "exportControlOff": {"zh_CN": "馈网控制 关", "en_US": "Export_control off"},
    "total": {"zh_CN": "总和方式", "en_US": "Total"},
    "per phase": {"zh_CN": "分相模式", "en_US": "Per phase"},
    "importControl_AELIO": {
        "zh_CN": "需量控制 {}, 设置值为 {} kW",
        "en_US": "Import_control {}, the value is {} kW",
    },
    "importControl": {
        "zh_CN": "需量控制 {}, 模式: {}, 设置值为 {} kW",
        "en_US": "Import_control {}, Control mode: {}, the value is {} kW",
    },
    "importControl_standby": {
        "zh_CN": "降低储能充电功率，直到待机",
        "en_US": "Reduce battery charge power until standby",
    },
    "importControl_discharge": {
        "zh_CN": "降低储能充电功率，必要时储能放电",
        "en_US": "Reduce battery charge power and discharge battery if necessary",
    },
    "importControlOff": {"zh_CN": "需量控制 关", "en_US": "Import_control off"},
    "workMode": {"zh_CN": "工作模式为 {}", "en_US": "Work_mode is {}"},
    "Self-use": {"zh_CN": "自发自用", "en_US": "Self-use"},
    "Feedin priority": {"zh_CN": "并网优先", "en_US": "Feedin priority"},
    "Back up mode": {"zh_CN": "备用模式", "en_US": "Back up mode"},
    "Manual mode": {"zh_CN": "手动模式 - {}", "en_US": "Manual mode - {}"},
    "Forced charging": {
        "zh_CN": "以{}kW的功率充电至{}%",
        "en_US": "Charge at a power of {} kW until it reaches {}%",
    },
    "Forced discharging": {
        "zh_CN": "以{}kW的功率放电至{}%",
        "en_US": "Discharge at a power of {} kW until it reaches {}%",
    },
    "Stop charging and discharging": {
        "zh_CN": "停止充放电",
        "en_US": "Stop charging and discharging",
    },
    "Peak Shaving": {"zh_CN": "削峰填谷", "en_US": "Peak Shaving"},
    "VPP": {"zh_CN": "VPP", "en_US": "VPP"},
    "Power Control Mode": {
        "zh_CN": "有功功率目标为 {}kW，无功功率目标为 {}kVar",
        "en_US": "Active power target is {}kW. Reactive power target is {}kVar",
    },
    "Electric Quantity Target Control Mode": {
        "zh_CN": "电能目标 {}kWh, 充放电功率目标 {}kW",
        "en_US": "Energy target is {}kWh, Charge or Discharge power target is {}kW",
    },
    "SOC Target Control Mode": {
        "zh_CN": "目标SOC {}%, 充放电功率目标 {}kW",
        "en_US": "target SOC is {}%, Charge or Discharge power target is {}kW",
    },
    "Push Power - Positive/Negative Mode": {
        "zh_CN": "电池功率目标 {}kW",
        "en_US": "Battery power target is {}kW",
    },
    "Push Power - Zero Mode": {
        "zh_CN": "电池不充放",
        "en_US": "Battery not charging or discharging",
    },
    "Self-Consume - Charge/Discharge Mode": {
        "zh_CN": "自发自用，电池仅从PV充电",
        "en_US": "Self-use. The battery can be charged from PV only",
    },
    "Self-Consume - Charge Only Mode": {
        "zh_CN": "自发自用，电池仅从PV充电并且不可放电",
        "en_US": "Self-use. The battery can be charged from PV only, and battery discharge is not allowed",
    },
    "PV&BAT Individual Setting – Duration Mode": {
        "zh_CN": "光伏功率目标 {}kW, 电池功率目标 {}kW",
        "en_US": "PV power target is {}kW. Battery power target is {}kW",
    },
    "PV&BAT Individual Setting – Target SOC Mode": {
        "zh_CN": "光伏功率目标 {}kW, 电池功率目标 {}kW, 目标SOC {}%",
        "en_US": "PV power target is {}kW. Battery power target is {}kW. target SOC is {}%",
    },
    "DoControl": {"zh_CN": "DO{}: {};", "en_US": "DO{}: {};"},
    "duration": {"zh_CN": "持续: {}秒", "en_US": "Last: {} seconds"},
    "systemSoc": {"zh_CN": "系统SOC {} {}%", "en_US": "System SOC {} {}%"},
    "systemImportPower": {
        "zh_CN": "电网买电功率 {} {}kW",
        "en_US": "Grid import power {} {}kW",
    },
    "systemExportPower": {
        "zh_CN": "电网馈电功率 {} {}kW",
        "en_US": "Grid export power {} {}kW",
    },
    "cabinetSoc": {"zh_CN": "机柜SOC {} {}%", "en_US": "Cabinet SOC {} {}%"},
    "cabinetAlarm": {
        "zh_CN": "机柜下属({})设备发生{}",
        "en_US": "The equipments({}) under the cabinet occurs {}",
    },
    "OR": {"zh_CN": "满足任一条件", "en_US": "Meet any of the conditions"},
    "AND": {"zh_CN": "满足所有条件", "en_US": "Meet all conditions"},
    "tips_alarm": {"zh_CN": "状态提醒", "en_US": "notice"},
    "normal_alarm": {"zh_CN": "一般告警", "en_US": "warning"},
    "emergency_alarm": {"zh_CN": "紧急告警", "en_US": "failure"},
    "pcs": {"zh_CN": "逆变器", "en_US": "Inverter"},
    "bms": {"zh_CN": "电池", "en_US": "Battery"},
    "elm": {
        "zh_CN": "电表",
        "en_US": "Meter",
    },
    "io": {"zh_CN": "IO模块", "en_US": "IO Module"},
    "air_conditioner": {"zh_CN": "空调", "en_US": "Air conditioner"},
    "liquid_cooling_unit": {"zh_CN": "液冷机组", "en_US": "Liquid Cooling Unit"},
    "environment_monitoring": {"zh_CN": "动环监控", "en_US": "Environmental Monitoring"},
    "ess": {"zh_CN": "机柜", "en_US": "Cabinet"},
}
